main — DarkHistory documentation

# main

The main DarkHistory function.

Methods

`evolve`([in_spec_elec, in_spec_phot, …]) | Main function computing histories and spectra.
`get_elec_cooling_data`(eleceng, photeng) | Returns electron cooling data for use in `main.evolve()`.
`get_tf`(rs, xHII, xHeII, dlnz[, coarsen_factor]) | Returns the interpolated transfer functions.

#### Previous topic

DarkHistory

#### Next topic

main.evolve

### This Page

Show Source